summaryrefslogtreecommitdiffstats
path: root/kmymoney2/widgets/kmymoneyaccountselector.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/widgets/kmymoneyaccountselector.h')
-rw-r--r--kmymoney2/widgets/kmymoneyaccountselector.h39
1 files changed, 20 insertions, 19 deletions
diff --git a/kmymoney2/widgets/kmymoneyaccountselector.h b/kmymoney2/widgets/kmymoneyaccountselector.h
index 2fc0635..632cdc5 100644
--- a/kmymoney2/widgets/kmymoneyaccountselector.h
+++ b/kmymoney2/widgets/kmymoneyaccountselector.h
@@ -56,10 +56,11 @@ class MyMoneyFile;
class kMyMoneyAccountSelector : public KMyMoneySelector
{
Q_OBJECT
+ TQ_OBJECT
public:
friend class AccountSet;
- kMyMoneyAccountSelector(QWidget *parent=0, const char *name=0, QWidget::WFlags flags = 0, const bool createButtons = true);
+ kMyMoneyAccountSelector(TQWidget *tqparent=0, const char *name=0, TQWidget::WFlags flags = 0, const bool createButtons = true);
virtual ~kMyMoneyAccountSelector();
/**
@@ -68,35 +69,35 @@ public:
* a list of specific account types only. In this case, pass
* a list of account types as parameter @p list.
*
* @param list QValueList of account types to be returned. If this
* list is empty (the default), then the ids of all accounts
* will be returned.
* @return QStringList of account ids
*/
- QStringList accountList(const QValueList<MyMoneyAccount::accountTypeE>& list = QValueList<MyMoneyAccount::accountTypeE>()) const;
+ TQStringList accountList(const TQValueList<MyMoneyAccount::accountTypeE>& list = TQValueList<MyMoneyAccount::accountTypeE>()) const;
- void setSelectionMode(QListView::SelectionMode mode);
+ void setSelectionMode(TQListView::SelectionMode mode);
/**
* This method checks if a given @a item matches the given regular expression @a exp.
*
* @param exp const reference to a regular expression object
* @param item pointer to QListViewItem
*
* @retval true item matches
* @retval false item does not match
*/
- virtual bool match(const QRegExp& exp, QListViewItem* item) const;
+ virtual bool match(const TQRegExp& exp, TQListViewItem* item) const;
/**
* This method returns, if any of the items in the selector contains
* the text @a txt.
*
* @param txt const reference to string to be looked for
* @retval true exact match found
* @retval false no match found
*/
- virtual bool contains(const QString& txt) const;
+ virtual bool tqcontains(const TQString& txt) const;
/**
* This method removes all the buttons of the widget
@@ -119,13 +120,13 @@ public slots:
protected:
/**
* This method loads the list of subaccounts as found in the
* @p list and attaches them to the parent widget passed as @p parent.
*
* @param parent pointer to parent widget
* @param list QStringList containing the ids of all subaccounts to load
* @return This method returns the number of accounts loaded into the list
*/
- int loadSubAccounts(QListViewItem* parent, const QStringList& list);
+ int loadSubAccounts(TQListViewItem* tqparent, const TQStringList& list);
/**
* This is a helper method for selectAllIncomeCategories()
@@ -149,8 +150,8 @@ protected:
KPushButton* m_noAccountButton;
KPushButton* m_incomeCategoriesButton;
KPushButton* m_expenseCategoriesButton;
- QValueList<int> m_typeList;
- QStringList m_accountList;
+ TQValueList<int> m_typeList;
+ TQStringList m_accountList;
};
@@ -166,7 +167,7 @@ public:
void clear(void);
int load(kMyMoneyAccountSelector* selector);
- int load(kMyMoneyAccountSelector* selector, const QString& baseName, const QValueList<QString>& accountIdList, const bool clear = false);
+ int load(kMyMoneyAccountSelector* selector, const TQString& baseName, const TQValueList<TQString>& accountIdList, const bool clear = false);
int count(void) const { return m_count; }
@@ -174,14 +175,14 @@ public:
bool isHidingClosedAccounts (void) { return m_hideClosedAccounts; }
protected:
- int loadSubAccounts(kMyMoneyAccountSelector* selector, QListViewItem* parent, const QString& key, const QStringList& list);
+ int loadSubAccounts(kMyMoneyAccountSelector* selector, TQListViewItem* tqparent, const TQString& key, const TQStringList& list);
bool includeAccount(const MyMoneyAccount& acc);
private:
int m_count;
MyMoneyFile* m_file;
- QValueList<MyMoneyAccount::accountTypeE> m_typeList;
- QListViewItem* m_favorites;
+ TQValueList<MyMoneyAccount::accountTypeE> m_typeList;
+ TQListViewItem* m_favorites;
bool m_hideClosedAccounts;
};
#endif
@@ -68,35 +69,35 @@ public:
* a list of account types as parameter @p list.
*
- * @param list QValueList of account types to be returned. If this
+ * @param list TQValueList of account types to be returned. If this
* list is empty (the default), then the ids of all accounts
* will be returned.
@@ -68,35 +69,35 @@ public:
* list is empty (the default), then the ids of all accounts
* will be returned.
- * @return QStringList of account ids
+ * @return TQStringList of account ids
*/
@@ -68,35 +69,35 @@ public:
*
* @param exp const reference to a regular expression object
- * @param item pointer to QListViewItem
+ * @param item pointer to TQListViewItem
*
* @retval true item matches
@@ -68,35 +69,35 @@ public:
/**
- * This method returns, if any of the items in the selector contains
+ * This method returns, if any of the items in the selector tqcontains
* the text @a txt.
*
@@ -119,13 +120,13 @@ public slots:
/**
* This method loads the list of subaccounts as found in the
- * @p list and attaches them to the parent widget passed as @p parent.
+ * @p list and attaches them to the tqparent widget passed as @p tqparent.
*
@@ -119,13 +120,13 @@ public slots:
*
- * @param parent pointer to parent widget
- * @param list QStringList containing the ids of all subaccounts to load
+ * @param tqparent pointer to tqparent widget
+ * @param list TQStringList containing the ids of all subaccounts to load
* @return This method returns the number of accounts loaded into the list
*/